% fit_common.m
%       Common code for doing the eps_r fit.

c0 = 2.998e8;

% Total measure distance (Tx to material plus material to Rx)
ops.D = 2*D;

% Fitting model and parameters
ops.model = 'lin';

% Linear model fitting ranges.
ops.lin_range.eps_real = [1 15 1401 0];
%ops.lin_range.eps_imag = [0 10 1001 0];
%ops.lin_range.eps_imag = [0 2 201 0];
ops.lin_range.eps_imag = [0 0.5 401 0];
%ops.lin_range.band = [4e9 40e9 19 0];  % 2 GHz segments
%ops.lin_range.band = [4e9 40e9 13 0];  % 3 GHz segments
ops.lin_range.band = [4e9 40e9 7 0];  % 6 GHz segments
ops.N_iter = 5;

% Cole model ranges to use (may need to adjust, this was for testing)
ops.cole_range.eps_inf = [1 10 51 0];
ops.cole_range.eps_s   = [1 10 51 0];
ops.cole_range.sig_s   = [1e-8 1e-2 9 1];
ops.cole_range.alpha_s = [0 1 11 0];
ops.cole_range.tau_s   = [1e-14 1e-6 9 1];

% Time-gating parameters
%ops.filt_type = 'none';
%ops.filt_type = 'kaiser2';  % Use separate kaiser windows for air and material
ops.filt_type = 'kaiser';   % Use same window for air and material
% Size of the time-gating window
ops.delta_w1 = kaiser_win(1)/c0;  % Time window width from peak to the left
ops.delta_w2 = kaiser_win(2)/c0;  % Time window width from peak to the right
ops.delta_tr = kaiser_win(3)/c0;  % Roll-off time of the window (left and right)
% Pass and stop-band deviation
ops.dev_pass_dB = 0.1;
ops.dev_stop_dB = -50;

% Plot result?
ops.do_plot = 2;

% Extension of data to avoid time-gating effects
ops.ext_data = [50 50 200];
%ops.ext_data = [];

data_air=load(fname_air);
S_air = data_air.S;
data_mat=load(fname_mat);
S_mat = data_mat.S;
f = data_air.f;

% Run the estimation function
[f_fit, eps_r_fit] = fit_eps_data(f, S_air, S_mat, d, ops);

