function [S, f] = na_msmt(h, M, start_f, stop_f, N_points, rbw, which);

% [S, f] = na_msmt(h, M, start_f, stop_f, N_points, rbw, which);
%
% Obtains S-parameters from network analyzer.
%
% Inputs:
%   h         Handle
%   M         Number of repeated measurements to do
%   start_f   Starting frequency
%   stop_f    Stop frequency
%   n_points  Number of points
%   rbw       Resolution bw
%   which     Which s-parameter to get 's11', 's12', 's21', 's22'
%
% Outputs:
%   S       S parameters
%   f       Frequency points

%common;

% Common parameters
%freq = 2e9 + 1e3 + 372;
%start_f = 2e9;
%stop_f = 5e9;
%rbw = 10e3;
%N_points = 101;
if N_points > 1,
    f = [0:N_points-1]*(stop_f - start_f)/(N_points-1) + start_f;
else
    f = start_f;
end

% fprintf('M=%d\n', M);

% Open the network analyzer
%h = vi_open(dev_na);

%% Network analyzer settings
% Read default settings for this measurement
% vi_write(h, sprintf('MMEM:LOAD:STAT 1,''C:\\Rohde&Schwarz\\Nwa\\RecallSets\\coup_meas_re_s11.zvx''\n'));

% Turn off continuous sweeping
vi_write(h, sprintf('INIT:CONT OFF\n'));

% Do measurement of S21
vi_write(h, sprintf('CALC1:PAR:MEAS "Trc1", "%s"\n', which));
% Set the range
vi_write(h, sprintf('SENS:FREQ:STAR %g\n', start_f));
vi_write(h, sprintf('SENS:FREQ:STOP %g\n', stop_f));
vi_write(h, sprintf('SENS:BAND:RES %g\n', rbw));
vi_write(h, sprintf('SENS:SWE:POIN %d\n', N_points));

T = do_sweep_mult(h, M);

wait_complete(h);

% fprintf('Done.\n');

% Read network analyzer data

% fprintf('Reading data...\n');
S = get_sweep_mult(h);

t = [0:M-1]/M*T;

%vi_close(h);


