function [S, f, t] = na_msmt_seg(h, M, f_segs, which);

% [S, f, t] = na_msmt_seg(h, M, f_segs, which);
%
% Obtains S-parameters from network analyzer.
%
% Inputs:
%   h         Handle
%   M         Number of repeated measurements to do
%   f_segs    Frequency segments
%	      [start stop N_pts pow_dbm time rbw]
%   which     Which s-parameter to get 's11', 's12', 's21', 's22'
%
% Outputs:
%   S       S parameters
%   f       Frequency points

%common;

% Common parameters
%freq = 2e9 + 1e3 + 372;
%start_f = 2e9;
%stop_f = 5e9;
%rbw = 10e3;
%N_points = 101;
%if N_points > 1,
%    f = [0:N_points-1]*(stop_f - start_f)/(N_points-1) + start_f;
%else
%    f = start_f;
%end

% fprintf('M=%d\n', M);

% Open the network analyzer
%h = vi_open(dev_na);

%% Network analyzer settings
% Read default settings for this measurement
% vi_write(h, sprintf('MMEM:LOAD:STAT 1,''C:\\Rohde&Schwarz\\Nwa\\RecallSets\\coup_meas_re_s11.zvx''\n'));

% Turn off continuous sweeping
vi_write(h, sprintf('INIT:CONT OFF\n'));

% Delete all existing traces (makes it faster)
vi_write(h, sprintf('CALC1:PAR:DEL:CALL\n'));

% Do measurement of selected parameters
if iscell(which),
  src_list = []; 
  for ii=1:length(which),
    vi_write(h, sprintf('CALC1:PAR:SDEF "Trc%d", "%s"\n', ii, which{ii}));
    s = which{ii};
    src1 = str2num(s(3));
    if isempty(src_list),
      src_list = src1;
    elseif ~(any(src_list == src1)),
      src_list = [src_list; src1];
    end
  end
else
  src_list = 1;
  vi_write(h, sprintf('CALC1:PAR:SDEF "Trc1", "%s"\n', which));
end
  
% Set the segments
vi_write(h, sprintf('SENS:SEGM:DEL:ALL\n'));
f_all = [];
for ii=size(f_segs, 1):-1:1
  f_start = f_segs(ii,1);
  f_stop = f_segs(ii,2);
  N_point = f_segs(ii,3);
  f_pow = f_segs(ii,4);
  f_time = f_segs(ii,5);
  f_rbw = f_segs(ii,6);
  vi_write(h, sprintf('SEGM:INS %f, %f, %d, %f, %f, 0, %f\n', f_start, f_stop, N_point, f_pow, f_time, f_rbw));
  if N_point > 1,
      f = [0:N_point-1]*(f_stop - f_start)/(N_point-1) + f_start;
  else
      f = f_start;
  end
  f_all = [f(:); f_all];
end

vi_write(h, sprintf('SWE:TYPE SEGM\n'));

% Set the sweep time if desired
vi_write(h, sprintf('SWE:TIME %f S\n', 0));

% Get the sweep time
sweep_time_s = vi_query(h, 'SEGM:SWE:TIME:SUM?');
sweep_time = sscanf(sweep_time_s, '%f', 1);
sweep_time = sweep_time*M*length(src_list);

fprintf('Start: Estimated %f seconds...\n', sweep_time);

T = do_sweep_mult(h, M);

tic;
wait_complete(h);
t = toc;

fprintf('Done: Actual %f seconds.\n', t);

% Read network analyzer data

% fprintf('Reading data...\n');
if ~iscell(which),
  S = get_sweep_mult(h);
else 
  S = get_sweep_mult_trc(h, length(which));
end
f = f_all;
t = [0:M-1]/M*t;

%t = [0:M-1]/M*T;

%vi_close(h);
%S = [];
%t = [];

