function [x_new, y_new, trim_idx] = extend_lpc(x, y, N_left, N_right, N);

% [x_new, y_new, trim_idx] = extend_lpc(x, y, N_left, N_right, N);
%
% Uses linear prediction to extend a signal on the left and
% right.


x = x(:);
y = y(:);


%% Extend on the left

if (N_left ~= 0),

  N_ext = N_left;

  % Reverse the signal
  y_rev = y(end:-1:1);
  % Get LPC coefficients
  a = mylpc(y_rev, N); a = a(:);
  % Extend N_ext times
  y_left = zeros(N_ext, 1);
  for ii=1:N_ext,
    y_left(ii) = -sum(a(2:end).*y_rev(end:-1:end-N+1)); 
    y_rev(end+1) = y_left(ii);
  end
  
  % Extend x range also
  dx = x(2)-x(1);
  x_left = x(1)+[-N_ext:-1].'*dx;
  y_left = y_left(end:-1:1);

else
  x_left = [];
  y_left = [];
end

if (N_right ~= 0),

  N_ext = N_right;
  y_fwd = y;
  
  % Get LPC coefficients
  a = mylpc(y_fwd, N); a = a(:);
  
  % Extend N_ext times
  y_right = zeros(N_ext, 1);
  for ii=1:N_ext,
    y_right(ii) = -sum(a(2:end).*y_fwd(end:-1:end-N+1)); 
    y_fwd(end+1) = y_right(ii);
  end
  
  % Extend x range also
  dx = x(2)-x(1);
  x_right = x(end)+[1:N_ext].'*dx;

else
  x_right = [];
  y_right = [];
end

x_new = [x_left; x; x_right];
y_new = [y_left; y; y_right];

% Get indices of original data
trim_idx = [1:length(y)].' + N_left;
