function [f_out, eps_r, s21_fit] = fit_eps(f, s21_meas, d, D, eps_real_rng, eps_imag_rng, N_band, band_df);

% [f_out, eps_r, s21_fit] = fit_eps(f, s21_meas, d, D, eps_real_rng, eps_imag_rng, N_band, band_df);
%
% Fits a measured response to modeled one.
%
% Inputs:
%       f               Frequency range of data
%       s21_meas        Measured and calibrated s21 response
%       d               Thickness of slab
%       D               distance from source to slab
%       eps_real_rng    Sample points for real part of eps_r
%       eps_imag_rng    Sample points for imag part of eps_r
%       N_band          Number of bands to consider (min should be 1)
%       band_df         Width of bands (Hz)

N_refl_order = 10;

f_out = [0:N_band]/(N_band)*(f(end)-f(1)) + f(1);
eps_r = zeros(size(f_out));

% Get stacked ranges of eps
eps_range = -j*kron(eps_imag_rng, ones(size(eps_real_rng))) + kron(ones(size(eps_imag_rng)), eps_real_rng);

for n=1:N_band+1,
  %% Get indices of frequencies to use
  % Get middle of band
  f0 = f_out(n);
  
  if (n==1),
    f1_0 = f0;
    f2_0 = (f_out(n)+f_out(n+1))/2;
  elseif (n==(N_band+1)),
    f1_0 = (f_out(n-1)+f_out(n))/2;
    f2_0 = f0;
  else
    f1_0 = (f_out(n-1)+f_out(n))/2;
    f2_0 = (f_out(n)+f_out(n+1))/2;
  end
  f_band = find((f >= f1_0) & (f <= f2_0));
  
  % Get extent of band to use for fit (Note: these can be overlapping)
  f1p = f0-band_df/2;
  f2p = f0+band_df/2;
  f_use = find((f >= f1p) & (f <= f2p));
  f1 = f(f_use);
  s21_meas1 = s21_meas(f_use);
  
  % Stack frequency and eps
  eps_range_ = kron(eps_range, ones(size(f1)));
  f_ = kron(ones(size(eps_range)), f1);

  % Build responses for all of the possible parameters
  s_ideal2c = get_S_tline2(d, D, eps_range_, f_, N_refl_order);

  % Minimize MSE
  s21_ = kron(ones(size(eps_range)), s21_meas1);
  err = mean(reshape(abs(s_ideal2c.S21 - s21_).^2, length(f1), length(eps_range)), 1);
  [val1 idx1] = min(err);

  %fprintf('Point %d: %.1f to %.1f\n', n, f1(1)/1e9, f1(end)/1e9);
  %s21__ = reshape(s_ideal2c.S21, length(f1), length(eps_range));
  %figure(10);
  %plot(f1, real(s21_meas1), f1, real(s21__(:,idx1)));
  %figure(11);
  %plot(f1, imag(s21_meas1), f1, imag(s21__(:,idx1)));
  %pause;
  
  % Fill in the eps_r values for this band
  eps_r(n) = eps_range(idx1);
end

% Interpolate values to get eps profile
eps_r_all = interp1(f_out, eps_r, f);

% Compute fitted response for all bands
tmp = get_S_tline2(d, D, eps_r_all, f, N_refl_order);
s21_fit = tmp.S21;
