function [f_out, eps_r, s21_fit] = fit_eps_c(f_in, s21_meas, d, D, eps_real_rng, eps_imag_rng, N_band, band_df, spread_type);

% [f_out, eps_r, s21_fit] = fit_eps_s(f, s21_meas, d, D, eps_real_rng, eps_imag_rng, N_band, band_df);
%
% Fits a measured response to modeled one.  Uses a fairly crude algorithm
% where a piecewise constant fit is performed in multiple overlapping bands.
% The results are then smoothed to obtain an average profile for eps_r.
% Doesn't always provide a very good fit.
%
% Inputs:
%       f               Frequency range of data
%       s21_meas        Measured and calibrated s21 response
%       d               Thickness of slab
%       D               distance from source to slab
%       eps_real_rng    Sample points for real part of eps_r
%       eps_imag_rng    Sample points for imag part of eps_r
%       N_band          Number of bands to consider (min should be 1)
%       band_df         Width of bands (Hz)

if (nargin < 9),
  spread_type = 1;
end

use_gpu = 1;
N_refl_order = 10;
log_level = 3;

fname_parm = 'fit_eps.in';
fname_parm_s = 'fit_eps_s.in';

% Generate parameter input file
f = fopen(fname_parm, 'wb');
fprintf(f, 'gpu %d\n', use_gpu);
fprintf(f, 'D %e\n', D);
fprintf(f, 'd %d\n', d);
fprintf(f, 'eps_real %e %e %d\n', eps_real_rng(1), eps_real_rng(end), length(eps_real_rng));
fprintf(f, 'eps_imag %e %e %d\n', eps_imag_rng(1), eps_imag_rng(end), length(eps_imag_rng));
fprintf(f, 'f %e %e %d\n', f_in(1), f_in(end), length(f_in));
fprintf(f, 'band %d %e\n', N_band, band_df);
fprintf(f, 'ord %d\n', N_refl_order);
fprintf(f, 'log %d\n', log_level);
fprintf(f, 'spread %d\n', spread_type);
fclose(f);

% Store S-parameters
f = fopen(fname_parm_s, 'wb');
for ii=1:length(s21_meas),
  fprintf(f, '%e %e\n', real(s21_meas(ii)), imag(s21_meas(ii)));
end
fclose(f);

% Execute the optimizer
fname_out = 'eps_r.out';
unix(sprintf('rm -rf %s', fname_out));
unix(sprintf('./fit_eps %s %s', fname_parm, fname_parm_s));

% Read results
f = fopen(fname_out, 'rb');
data = fscanf(f, '%e', Inf);
data = reshape(data, 2, length(data)/2);
eps_r = data(1, :) + j*data(2,:);

f_out = [0:N_band]/N_band*(f_in(end)-f_in(1)) + f_in(1);

% Interpolate values to get eps profile
eps_r_all = interp1(f_out, eps_r, f_in);

% Compute fitted response for all bands
tmp = get_S_tline2(d, D, eps_r_all, f_in, N_refl_order, spread_type);
s21_fit = tmp.S21;

