function [parm, eps_r, s21_fit] = fit_eps_cole_c(f_in, s21_meas, d, D, ranges, spread_type);

% [f_out, eps_r, s21_fit] = fit_eps_cole_s(f, s21_meas, d, D, ranges);
%
% Fits a measured response to modeled one using the cole-cole model.
%
% Inputs:
%       f               Frequency range of data
%       s21_meas        Measured and calibrated s21 response
%       d               Thickness of slab
%       D               distance from source to slab
%       ranges          Cole parameter ranges: [start stop N log] 
%                       eps_inf
%                       eps_s
%                       sig_s
%                       alpha_s
%                       tau_s

if (nargin < 9),
  spread_type = 1;
end

use_gpu = 1;
N_refl_order = 10;
log_level = 3;

fname_parm = 'fit_eps.in';
fname_parm_s = 'fit_eps_s.in';

eps_inf_rng = ranges.eps_inf;
eps_s_rng = ranges.eps_s;
sig_s_rng = ranges.sig_s;
alpha_s_rng = ranges.alpha_s;
tau_s_rng = ranges.tau_s;

% Generate parameter input file
f = fopen(fname_parm, 'wb');
fprintf(f, 'gpu %d\n', use_gpu);
fprintf(f, 'D %e\n', D);
fprintf(f, 'd %d\n', d);
fprintf(f, 'eps_inf %e %e %d %d\n', eps_inf_rng);
fprintf(f, 'eps_s %e %e %d %d\n', eps_s_rng);
fprintf(f, 'sig_s %e %e %d %d\n', sig_s_rng);
fprintf(f, 'alpha_s %e %e %d %d\n', alpha_s_rng);
fprintf(f, 'tau_s %e %e %d %d\n', tau_s_rng);
fprintf(f, 'f %e %e %d\n', f_in(1), f_in(end), length(f_in));
fprintf(f, 'ord %d\n', N_refl_order);
fprintf(f, 'log %d\n', log_level);
fprintf(f, 'spread %d\n', spread_type);
fclose(f);

% Store S-parameters
f = fopen(fname_parm_s, 'wb');
for ii=1:length(s21_meas),
  fprintf(f, '%e %e\n', real(s21_meas(ii)), imag(s21_meas(ii)));
end
fclose(f);

% Execute the optimizer
fname_out = 'parm_fit.out';
unix(sprintf('rm -rf %s', fname_out));
unix(sprintf('./fit_eps_cole %s %s', fname_parm, fname_parm_s));

% Read results
f = fopen(fname_out, 'rb');
data = fscanf(f, '%e', Inf);
parm = [];
parm.eps_inf = data(1);
parm.eps_s = data(2);
parm.sig_s = data(3);
parm.alpha_s = data(4);
parm.tau_s = data(5);
fclose(f);

% Compute the cole-cole model.
eps0 = 8.854e-12;
eps_r = parm.eps_inf + (parm.eps_s - parm.eps_inf)./(1.0 + (j*2*pi*f_in*parm.tau_s).^(1-parm.alpha_s)) - j*parm.sig_s./(2*pi*f_in*eps0);

% Compute fitted response for all bands
tmp = get_S_tline2(d, D, eps_r, f_in, N_refl_order, spread_type);
s21_fit = tmp.S21;



