function [S] = get_S_tline2(d, D, eps_r, f, N, spread_type);

% [S] = get_S_tline2(d, eps_r, f, N, spread_type);
%
% Get the S-parameters of a transmission line model.  Finds S21
% using a series, which allows 3D spreading in the sample to
% be taken into account.
%
% Inputs:
%	  d	  Thickness of the sample (m)
%         D       Distance from source to sample (m)
%	  eps_r	  Relative dielectric constant of sample
%	  f	  Frequency (Hz)
%         N       Series order
%       spread_type

if (nargin < 6),
  spread_type = 1;
end

ff = f(:);
eps_r = eps_r(:);

c0 = 2.998e8;
eta0 = 376.7;
  
Nf = length(f);

beta = 2*pi*ff.*sqrt(eps_r)/c0;
theta = beta*d;
eta = eta0./sqrt(eps_r);	% Want this to be complex?

G0 = (eta-eta0)./(eta+eta0);
A = exp(-j*theta);

S21_all = zeros(Nf, N+1);

if (spread_type == 0),
  T0 = A;
elseif (spread_type == 1),
  T0 = A*(D/(D+d));
elseif (spread_type == 2),
  T0 = A*sqrt(D/(D+d));
end

S21_all(:,1) = (1+G0).*T0;

for n=1:N,
  if (spread_type == 0),
    T_2n_m1 = A;
    T_2n = A;
  elseif (spread_type == 1),
    T_2n_m1 = A*((D+(2*n-1)*d)/(D+2*n*d));
    T_2n = A*((D+(2*n)*d)/(D+(2*n+1)*d));
  elseif (spread_type == 2),
    T_2n_m1 = A*sqrt((D+(2*n-1)*d)/(D+2*n*d));
    T_2n = A*sqrt((D+(2*n)*d)/(D+(2*n+1)*d));
  end
  S21_all(:,n+1) = S21_all(:,n).*G0.^2.*T_2n_m1.*T_2n;
end

S.S21 = reshape(sum(S21_all,2).*(1-G0), size(f));

  
  
  
