function [S] = get_S_tline3(d, D, eps_r, f, N, spread_type);

% [S] = get_S_tline3(d, D, eps_r, f, N, spread_type);
%
% Get the S-parameters of a transmission line model.  Finds S21
% using a series, which allows 3D spreading in the sample to
% be taken into account.  Uses simplified algorithm like
% in paper.
%
% Inputs:
%	  d	  Thickness of the sample (m)
%         D       Total distance from antennas to sample.
%	  eps_r	  Relative dielectric constant of sample
%	  f	  Frequency (Hz)
%         N       Series order
%       spread_type

if (nargin < 7),
  spread_type = 1;
end

ff = f(:);
eps_r = eps_r(:);

c0 = 2.998e8;
eta0 = 376.7;
  
Nf = length(f);

beta = 2*pi*ff.*sqrt(eps_r)/c0;
theta = beta*d;
eta = eta0./sqrt(eps_r);	% Want this to be complex?

G0 = (eta-eta0)./(eta+eta0);
T0 = exp(-j*theta);

S21_all = zeros(Nf, N+1);

if (spread_type == 0),
  gn = 1;
elseif (spread_type == 1),
  gn = (D/(D+d));
elseif (spread_type == 2),
  gn = sqrt(D/(D+d));
end

S21_prev = (1+G0).*T0;
S21_all(:,1) = S21_prev*gn;

for n=1:N,
  if (spread_type == 0),
    gn = 1;
  elseif (spread_type == 1),
    gn = (D/(D+(2*n+1)*d));
  elseif (spread_type == 2),
    gn = sqrt(D/(D+(2*n+1)*d));
  end
  S21_prev = S21_prev.*G0.^2.*T0.^2;
  S21_all(:,n+1) = S21_prev*gn;
end

S.S21 = reshape(sum(S21_all,2).*(1-G0), size(f));

  
  
  
